@@ -83,6 +83,9 @@ __RCSID("$Id: acl.c,v 1.118 2016/11/24 03:59:40 manu Exp $");
 #ifdef USE_GEOIP
 #include "geoip.h"
 #endif
+#ifdef USE_GEOIP2
+#include "geoip2.h"
+#endif
 #ifdef USE_P0F
 #include "p0f.h"
 #endif
@@ -427,6 +430,16 @@ struct acl_clause_rec acl_clause_rec[] = {
 	  acl_print_list, acl_add_list, 
 	  NULL, acl_list_filter },
 #endif
+#ifdef USE_GEOIP2
+	{ AC_GEOIP, MULTIPLE_OK, AS_ANY, "geoip",
+	  AT_STRING, AC_GEOIP_LIST, AC_STRING, EXF_GEOIP,
+	  acl_print_string, acl_add_string,
+	  acl_free_string, geoip2_filter },
+	{ AC_GEOIP_LIST, MULTIPLE_OK, AS_ANY, "geoip_list",
+	  AT_LIST, AC_NONE, AC_NONE, EXF_GEOIP,
+	  acl_print_list, acl_add_list,
+	  NULL, acl_list_filter },
+#endif
 #ifdef USE_P0F
 	{ AC_P0F, MULTIPLE_OK, AS_ANY, "p0f", 
 	  AT_STRING, AC_P0F_LIST, AC_STRING, EXF_P0F,
@@ -1938,7 +1951,7 @@ acl_print_nsupdate(ad, buf, len)
 	char *buf;
 	size_t len;
 {
-	(void)snprintf(buf, len, "$%s ", ad->nsupdate->nse_name);
+	(void)snprintf(buf, len, "$%s ", nsupdate_get_name(ad->nsupdate));
 
 	return buf;
 }
