@@ -1,4 +1,4 @@
-/* $Id: acl.h,v 1.54 2013/08/27 13:50:44 manu Exp $ */
+/* $Id: acl.h,v 1.57 2016/11/02 17:41:05 manu Exp $ */
 
 /*
  * Copyright (c) 2004-2012 Emmanuel Dreyfus
@@ -68,6 +68,9 @@ typedef enum {
 	AC_FROM,
 	AC_FROM_RE,
 	AC_FROM_LIST,
+	AC_RAWFROM,
+	AC_RAWFROM_RE,
+	AC_RAWFROM_LIST,
 	AC_RCPT,
 	AC_RCPT_RE,
 	AC_RCPT_LIST,
@@ -94,6 +97,7 @@ typedef enum {
 	AC_URLCHECK_LIST,
 	AC_LDAPCHECK,
 	AC_PROP_STR,
+	AC_PROP_GLOB,
 	AC_PROP_NUM,
 	AC_PROP_PROP,
 	AC_PROP_RE,
@@ -182,6 +186,7 @@ struct acl_param {
 	char *ap_msg;
 	char *ap_report;
 	char *ap_addheader;
+	int ap_addheader_index;
 	char *ap_addfooter;
 	char *ap_subjtag;
 	int ap_maxpeek;
@@ -289,6 +294,7 @@ struct acl_entry {
 	char *a_msg;
 	char *a_report;
 	char *a_addheader;
+	int a_addheader_index;
 	char *a_addfooter;
 	char *a_subjtag;
 	int a_maxpeek;
@@ -316,7 +322,7 @@ void acl_add_code(char *);
 void acl_add_ecode(char *);
 void acl_add_msg(char *);
 void acl_add_report(char *);
-void acl_add_addheader(char *);
+void acl_add_addheader(char *, int);
 void acl_add_addfooter(char *);
 void acl_add_subjtag(char *);
 void acl_add_maxpeek(int);
@@ -340,8 +346,12 @@ int acl_helo_regexec(acl_data_t *, acl_stage_t,
 		     struct acl_param *, struct mlfi_priv *);
 int acl_from_cmp(acl_data_t *, acl_stage_t, 
 		 struct acl_param *, struct mlfi_priv *);
+int acl_rawfrom_cmp(acl_data_t *, acl_stage_t, 
+		 struct acl_param *, struct mlfi_priv *);
 int acl_from_regexec(acl_data_t *, acl_stage_t, 
 		 struct acl_param *, struct mlfi_priv *);
+int acl_rawfrom_regexec(acl_data_t *, acl_stage_t, 
+		 struct acl_param *, struct mlfi_priv *);
 int acl_rcpt_cmp(acl_data_t *, acl_stage_t, 
 		 struct acl_param *, struct mlfi_priv *);
 int acl_rcpt_regexec(acl_data_t *, acl_stage_t, 
@@ -406,9 +416,9 @@ int acl_modify_by_prop(char *, char *, struct acl_param *);
 #define EXF_HELO	(1LL << 26)
 #define EXF_LDAPCHECK	(1LL << 27)
 #define EXF_NOLOG	(1LL << 28)
-#define	EXF_DKIM	(1LL << 28)
 #define EXF_P0F		(1LL << 29)
 #define EXF_SA		(1LL << 30)
 #define EXF_TARPIT	(1LL << 31)
 #define EXF_MX		(1LL << 32) /* Need long long (64b) */
+#define	EXF_DKIM	(1LL << 33)
 #endif /* _ACL_H_ */
