@@ -1,4 +1,4 @@
-/* $Id: conf.c,v 1.69 2010/06/16 01:30:30 manu Exp $ */
+/* $Id: conf.c,v 1.74 2014/02/04 15:19:25 manu Exp $ */
 
 /*
  * Copyright (c) 2004-2010 Emmanuel Dreyfus
@@ -34,11 +34,11 @@
 #ifdef HAVE_SYS_CDEFS_H
 #include <sys/cdefs.h>
 #ifdef __RCSID
-__RCSID("$Id: conf.c,v 1.69 2010/06/16 01:30:30 manu Exp $");
+__RCSID("$Id: conf.c,v 1.74 2014/02/04 15:19:25 manu Exp $");
 #endif
 #endif
 
-#ifdef HAVE_OLD_QUEUE_H
+#if defined(HAVE_OLD_QUEUE_H) || !defined(HAVE_SYS_QUEUE_H)
 #include "queue.h"
 #else 
 #include <sys/queue.h>
@@ -449,6 +449,7 @@ conf_defaults(c)
 	c->c_acldebug = 0;
 	c->c_quiet = 0;
 	c->c_noauth = 0;
+	c->c_multiracl = 0;
 	c->c_noaccessdb = 0;
 	c->c_nospf = 0;
 	c->c_delayedreject = 0;
@@ -476,6 +477,7 @@ conf_defaults(c)
 	c->c_dumpfreq = DUMPFREQ;
 	c->c_timeout = TIMEOUT;
 	c->c_extendedregex = 0;
+	c->c_unbracket = 0;
 	c->c_dracdb = DRACDB;
 	c->c_nodrac = 0;
 	c->c_maxpeek = 0;
@@ -489,5 +491,7 @@ conf_defaults(c)
 	c->c_spamdsocktype[0] = '\0';
 #endif
 	c->c_syncmaxqlen = SYNC_MAXQLEN;
+	(void)memset(&c->c_localaddr, 0, sizeof(c->c_localaddr));
+	(void)memset(&c->c_localaddr_string, 0, sizeof(c->c_localaddr_string));
 	return;
 }
