@@ -60,6 +60,9 @@ __RCSID("$Id: dnsrbl.c,v 1.31 2016/01/03 05:06:32 manu Exp $");
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <arpa/nameser.h>
+#ifdef __APPLE__
+#include <arpa/nameser_compat.h>
+#endif
 #include <resolv.h>
 #ifndef NS_MAXMSG
 #define NS_MAXMSG	65535
