@@ -1,4 +1,4 @@
-/* $Id: macro.c,v 1.9 2008/11/18 11:57:29 manu Exp $ */
+/* $Id: macro.c,v 1.10 2013/01/19 16:01:15 manu Exp $ */
 
 /*
  * Copyright (c) 2006 Emmanuel Dreyfus
@@ -34,7 +34,7 @@
 #ifdef HAVE_SYS_CDEFS_H
 #include <sys/cdefs.h>
 #ifdef __RCSID
-__RCSID("$Id: macro.c,v 1.9 2008/11/18 11:57:29 manu Exp $");
+__RCSID("$Id: macro.c,v 1.10 2013/01/19 16:01:15 manu Exp $");
 #endif
 #endif
 
@@ -47,7 +47,7 @@ __RCSID("$Id: macro.c,v 1.9 2008/11/18 11:57:29 manu Exp $");
 #include <sysexits.h>
 #include <regex.h>
 
-#ifdef HAVE_OLD_QUEUE_H 
+#if defined(HAVE_OLD_QUEUE_H) || !defined(HAVE_SYS_QUEUE_H) 
 #include "queue.h"
 #else 
 #include <sys/queue.h>
