@@ -1,4 +1,4 @@
-/* $Id: milter-greylist.c,v 1.283 2016/11/24 03:59:40 manu Exp $ */
+/* $Id: milter-greylist.c,v 1.284 2017/07/11 03:17:33 manu Exp $ */
 
 /*
  * Copyright (c) 2004-2012 Emmanuel Dreyfus
@@ -34,7 +34,7 @@
 #ifdef HAVE_SYS_CDEFS_H
 #include <sys/cdefs.h>
 #ifdef __RCSID  
-__RCSID("$Id: milter-greylist.c,v 1.283 2016/11/24 03:59:40 manu Exp $");
+__RCSID("$Id: milter-greylist.c,v 1.284 2017/07/11 03:17:33 manu Exp $");
 #endif
 #endif
 
@@ -107,6 +107,9 @@ static int check_drac(char *dotted_ip);
 #ifdef USE_GEOIP
 #include "geoip.h"
 #endif
+#ifdef USE_GEOIP2
+#include "geoip2.h"
+#endif
 #ifdef USE_P0F
 #include "p0f.h"
 #endif
@@ -339,7 +342,7 @@ tarpit_reentry(priv)
 		tuple.salen = priv->priv_addrlen;
 		tuple.from = priv->priv_from;
 		tuple.rcpt = priv->priv_rcpt.lh_first->r_addr;
-		tuple.autowhite = 0;
+		tuple.autowhite = priv->priv_sr.sr_autowhite;
 		tuple.updatetype = TU_AUTOWHITE;
 
 		mg_tuple_update(&tuple);
@@ -424,6 +427,9 @@ real_connect(ctx, hostname, addr)
 #ifdef USE_GEOIP
 	geoip_set_ccode(priv);
 #endif
+#ifdef USE_GEOIP2
+	geoip2_set_ccode(priv);
+#endif
 #ifdef HAVE_SPF2
 	priv->priv_spf_header = NULL;
 #endif
@@ -877,8 +883,8 @@ real_header(ctx, name, value)
 	    (priv->priv_buflen > priv->priv_maxpeek)) {
 		if (conf.c_debug)
 			mg_log(LOG_DEBUG, 
-			    "ignoring message beyond maxpeek = %d", 
-			    priv->priv_maxpeek);
+			    "%s: ignoring message beyond maxpeek = %d", 
+			    priv->priv_queueid, priv->priv_maxpeek);
 		priv->priv_maxpeek = 0;
 		return SMFIS_CONTINUE;
 	}
@@ -987,8 +993,8 @@ real_body(ctx, chunk, size)
 	if (priv->priv_peekcount >= priv->priv_maxpeek) {
 		if (!priv->priv_peekdone) {
 			mg_log(LOG_DEBUG, 
-			       "ignoring message beyond maxpeek = %d", 
- 			       priv->priv_maxpeek);
+			       "%s: ignoring message beyond maxpeek = %d", 
+ 			       priv->priv_queueid, priv->priv_maxpeek);
 			priv->priv_peekdone = 1;
 		}
 		return SMFIS_CONTINUE;
@@ -1296,7 +1302,7 @@ passed:
 
 	/* Add subject tag if we have the whole message */
 	if (priv->priv_sr.sr_subjtag) {
-		const char const subjhdr[] = "Subject: ";
+		const char subjhdr[] = "Subject: ";
 		size_t subjhdrlen = sizeof(subjhdr) - 1;
 		char *tag;
 		struct line *l;
@@ -1852,6 +1858,9 @@ main(argc, argv)
 #endif
 #ifdef USE_GEOIP
 	geoip_init();
+#endif
+#ifdef USE_GEOIP2
+	geoip2_init();
 #endif
 	macro_init();
 	ratelimit_init();
@@ -3244,7 +3253,7 @@ fstring_expand(priv, rcpt, fstring, cv)
 			break;
 		}
 		case 'C': {	/* Country code from GeoIP */
-#ifdef USE_GEOIP
+#if defined(USE_GEOIP) || defined(USE_GEOIP2)
 			if (priv->priv_ccode != NULL)
 				mystrncat(&outstr, 
 					  priv->priv_ccode, 
