@@ -60,6 +60,25 @@ __RCSID("$Id: nsupdate.c,v 1.4 2016/01/31 05:35:38 manu Exp $");
 #include "acl.h"
 #include "store.h"
 
+struct tsig_entry {
+	ns_tsig_key tse_tsig;
+	LIST_ENTRY(tsig_entry) tse_list;
+};
+
+struct nsupdate_entry {
+	res_state nse_res; /* for runtime only */
+	char *nse_servers; /* for config only */
+	char *nse_name;
+	char *nse_rname;
+	int nse_ttl;
+	int nse_class;
+	int nse_type;
+	char *nse_rvalue;
+	ns_tsig_key *nse_tsig;
+	LIST_ENTRY(nsupdate_entry) nse_list;
+};
+
+
 LIST_HEAD(tsig_head, tsig_entry) tsig_head =
     LIST_HEAD_INITIALIZER(tsig_head);
 LIST_HEAD(nsupdate_head, nsupdate_entry) nsupdate_head =
@@ -79,7 +98,7 @@ nsupdate_init(void)
 	return;
 }
 
-static const char const base64_translate[] = {
+static const char base64_translate[] = {
     -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
     -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
     -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 62, -1, -1, -1, 63,
@@ -469,6 +488,12 @@ nsupdate_add(name)
 	return 0;
 }
 
+char *
+nsupdate_get_name(struct nsupdate_entry *nse) 
+{
+        return nse->nse_name;
+}
+
 int 
 nsupdate_filter(ad, stage, ap, priv)
 	acl_data_t *ad; 
@@ -536,4 +561,5 @@ nsupdate_clear(void)
 	}
 }
 
+
 #endif /* USE_NSUPDATE */
