@@ -1,4 +1,4 @@
-/* $Id: pending.c,v 1.92 2010/04/12 12:04:41 manu Exp $ */
+/* $Id: pending.c,v 1.93 2013/01/19 16:01:15 manu Exp $ */
 
 /*
  * Copyright (c) 2004 Emmanuel Dreyfus
@@ -34,11 +34,11 @@
 #ifdef HAVE_SYS_CDEFS_H
 #include <sys/cdefs.h>
 #ifdef __RCSID  
-__RCSID("$Id: pending.c,v 1.92 2010/04/12 12:04:41 manu Exp $");
+__RCSID("$Id: pending.c,v 1.93 2013/01/19 16:01:15 manu Exp $");
 #endif
 #endif
 
-#ifdef HAVE_OLD_QUEUE_H 
+#if defined(HAVE_OLD_QUEUE_H) || !defined(HAVE_SYS_QUEUE_H) 
 #include "queue.h"
 #else
 #include <sys/queue.h>
@@ -504,14 +504,12 @@ pending_tarpitted(sa, salen, from, rcpt)
 	struct pending *pending;
 	struct pending *next;
 	struct timeval tv;
-	time_t now;
 	int dirty = 0;
 	struct pending_bucket *b;
 	ipaddr *mask = NULL;
 	time_t tarpitted = -1;
 
 	(void)gettimeofday(&tv, NULL);
-	now = tv.tv_sec;
 
 	b = &pending_buckets[BUCKET_HASH(sa, from, rcpt, PENDING_BUCKETS)];
 	PENDING_LOCK;
