@@ -1,4 +1,4 @@
-/* $Id: urlcheck.c,v 1.35 2009/06/08 23:40:06 manu Exp $ */
+/* $Id: urlcheck.c,v 1.43 2013/01/19 16:01:15 manu Exp $ */
 
 /*
  * Copyright (c) 2006-2007 Emmanuel Dreyfus
@@ -36,7 +36,7 @@
 #ifdef HAVE_SYS_CDEFS_H
 #include <sys/cdefs.h>
 #ifdef __RCSID
-__RCSID("$Id: urlcheck.c,v 1.35 2009/06/08 23:40:06 manu Exp $");
+__RCSID("$Id: urlcheck.c,v 1.43 2013/01/19 16:01:15 manu Exp $");
 #endif
 #endif
 
@@ -50,7 +50,7 @@ __RCSID("$Id: urlcheck.c,v 1.35 2009/06/08 23:40:06 manu Exp $");
 #include <sysexits.h>
 #include <signal.h>
 
-#ifdef HAVE_OLD_QUEUE_H 
+#if defined(HAVE_OLD_QUEUE_H) || !defined(HAVE_SYS_QUEUE_H) 
 #include "queue.h"
 #else 
 #include <sys/queue.h>
@@ -77,8 +77,8 @@ struct urlcheck_data {
 #define BOUNDARY_LEN	4
 struct post_data {
 	struct mlfi_priv *pd_priv;
-	struct header *pd_curhdr;
-	struct body *pd_curbody;
+	struct line *pd_curhdr;
+	struct line *pd_curbody;
 	char *pd_curptr;
 	int pd_done;
 	char pd_boundary[BOUNDARY_LEN + 1];
@@ -287,20 +287,19 @@ find_boundary(priv, boundary)
 	char *boundary;
 {
 	int i;
-	struct body *b;
-	struct header *h;
+	struct line *l;
 
 	for (i = 0; i < BOUNDARY_LEN; i++)
 		boundary[i] = 'a';
 	boundary[BOUNDARY_LEN] = '\0';
 
 	do {
-		TAILQ_FOREACH(h, &priv->priv_header, h_list)
-			if (strstr(h->h_line, boundary) != NULL)
+		TAILQ_FOREACH(l, &priv->priv_header, l_list)
+			if (strstr(l->l_line, boundary) != NULL)
 				goto next;
 			
-		TAILQ_FOREACH(b, &priv->priv_body, b_list)
-			if (strstr(b->b_lines, boundary) != NULL)
+		TAILQ_FOREACH(l, &priv->priv_body, l_list)
+			if (strstr(l->l_line, boundary) != NULL)
 				goto next;
 
 		return 0;
@@ -341,7 +340,7 @@ curl_post(buffer, size, nmemb, userp)
 			exit(EX_OSERR);
 		}
 		snprintf(buffer, len, post_header_templ, pd->pd_boundary);
-		pd->pd_curptr = pd->pd_curhdr->h_line;
+		pd->pd_curptr = pd->pd_curhdr->l_line;
 		goto finish;
 	}
 
@@ -356,16 +355,16 @@ curl_post(buffer, size, nmemb, userp)
 			if (len > 0)
 				memcpy(buffer, pd->pd_curptr, len);
 
-			pd->pd_curhdr = TAILQ_NEXT(pd->pd_curhdr, h_list);
+			pd->pd_curhdr = TAILQ_NEXT(pd->pd_curhdr, l_list);
 
 			/* 
 			 * If there are no more headers, we will move to
 			 * the body on next time we are called.
 			 */
 			if (pd->pd_curhdr == NULL) 
-				pd->pd_curptr = pd->pd_curbody->b_lines;
+				pd->pd_curptr = pd->pd_curbody->l_line;
 			else
-				pd->pd_curptr = pd->pd_curhdr->h_line;
+				pd->pd_curptr = pd->pd_curhdr->l_line;
 
 		} else { /* (len > size * nmemb) */
 			/* 
@@ -389,11 +388,11 @@ curl_post(buffer, size, nmemb, userp)
 
 			/* Move to the next one */
 			pd->pd_curbody = 
-			    TAILQ_NEXT(pd->pd_curbody, b_list);
+			    TAILQ_NEXT(pd->pd_curbody, l_list);
 
 			/* If it's not the last one... */
 			if (pd->pd_curbody != NULL)
-				pd->pd_curptr = pd->pd_curbody->b_lines;
+				pd->pd_curptr = pd->pd_curbody->l_line;
 			else
 				pd->pd_curptr = NULL;
 		} else {
@@ -535,6 +534,66 @@ get_cnx(ue)
 	return cnx;
 }
 
+char *
+urlencode(str)
+	char *str;
+{
+	char *outstr;
+	size_t origlen, len;
+	char *cp;
+	char *dp;
+
+	origlen = strlen(str) + 1;
+	len = origlen;
+	for (cp = str; *cp; cp++) {
+		if (isalnum((int)*cp))
+			continue;
+
+		switch(*cp) {
+		case '-':
+		case '_':
+		case '.':
+		case '~':
+			break;
+		default:
+			len += 2;
+			break;
+		}
+	}
+
+	if (len == origlen)
+		return NULL;
+
+	if ((outstr = malloc(len)) == NULL) {
+		mg_log(LOG_ERR, "malloc failed");
+		exit (EX_OSERR);
+	}
+
+	dp = outstr;
+	for (cp = str; *cp; cp++) {
+		if (isalnum((int)*cp)) {
+			*dp++ = *cp;
+			continue;
+		}
+
+		switch(*cp) {
+		case '-':
+		case '_':
+		case '.':
+		case '~':
+			*dp++ = *cp;
+			break;
+		default:
+			(void)sprintf(dp, "%%%02X", *cp);
+			dp += 3;
+			break;
+		}
+	}
+
+	*dp = '\0';
+
+	return outstr;
+}
 
 int
 urlcheck_validate(ad, stage, ap, priv)
@@ -550,10 +609,13 @@ urlcheck_validate(ad, stage, ap, priv)
 	struct urlcheck_data ud;
 	struct urlcheck_cnx *cnx;
 	struct timeval tv1, tv2, tv3;
+	char *(*cv)(char *);
 
 	rcpt = priv->priv_cur_rcpt;
 	ue = ad->urlcheck;
-	url = fstring_expand(priv, rcpt, ue->u_url);
+
+	cv = (ue->u_flags & U_NOENCODE) ? NULL : *urlencode;
+	url = fstring_expand(priv, rcpt, ue->u_url, cv);
 
 	if (conf.c_debug) {
 		mg_log(LOG_DEBUG, "checking \"%s\"\n", url);
@@ -1095,7 +1157,7 @@ answer_parse(data, ap, flags, priv)
 	 */
 	if (flags & U_GETPROP) {
 		if (retval == 0)
-			prop_clear_tmp(priv);
+			prop_clear(priv, UP_TMPPROP);
 		else
 			prop_untmp(priv);
 	}
